==> haskell-yesod-static-1.5.0.3-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-static/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.0.3
id: yesod-static-1.5.0.3-eedd29060a6c50d43c62f00258917a62
key: yesod_LXZRqe6Nhja6yvgRkrvb4N
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Static Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Generators
    Yesod.EmbeddedStatic.Types Yesod.EmbeddedStatic.Css.AbsoluteUrl
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
hs-libraries: HSyesod-static-1.5.0.3-LXZRqe6Nhja6yvgRkrvb4N
depends:
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    attoparsec-0.13.0.1-57451b44323b331c08be1b712bdc3810
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
    conduit-extra-1.1.9.2-1bef4166ec3f53ae2e6d2e9011cd9cbe
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
    cryptohash-conduit-0.1.1-efae13840ebbb4413a12b1a104e96ba5
    css-text-0.1.2.1-560c0698a8f53de36ee4bd610e239c26
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.9-bf7d929a6dc69a119cb69a6302803375
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    hashable-1.2.4.0-44b2533f61c94bc76cb2b27e15566721
    hjsmin-0.1.5.1-01bd3cdce5da2c634084ee1f0202fa88
    http-types-0.9-26f1bedc2b9255e48a8e673fef6095b1
    mime-types-0.1.0.6-4baf8227dab0a657ebdceeda13c342d3
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
    wai-3.2.0-a50c1f56084e726fac99a6d8758a9179
    wai-app-static-3.1.4.1-b2581d51484b07a66047b889aceeccc4
    yesod-core-1.4.18.1-1427f09c60204e2c904ad1c11de4a4ba
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.5.0.3-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-static/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.0.3
id: yesod-static-1.5.0.3-e9f0c8d7734acc624477d4bd14f9f680
key: yesod_JzID1Nag8qyIRjchB7byup
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Static Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Generators
    Yesod.EmbeddedStatic.Types Yesod.EmbeddedStatic.Css.AbsoluteUrl
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
hs-libraries: HSyesod-static-1.5.0.3-JzID1Nag8qyIRjchB7byup
depends:
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
    conduit-extra-1.1.9.2-fc66bf7a229ea809b0bdda20349fc384
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
    cryptohash-conduit-0.1.1-7ac7a6a4f10fa383c5d57a5fb77f5cf0
    css-text-0.1.2.1-9e91a6e24ab9d04d01b694bbf376f115
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    hjsmin-0.1.5.1-1b718142efced76f4fbd2dca7056fef1
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
    wai-3.2.0-ef5213f36cb00369a3d68c2dd00424b9
    wai-app-static-3.1.4.1-8b8a073b4a361f850a3a24fe50a34bad
    yesod-core-1.4.18.2-1c2aab5a100ce9de89ec3a6e919507f9
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
